ExecutionContext

Struct ExecutionContext 

pub(crate) struct ExecutionContext {
    dry_run: DryRun,
    pub(crate) verbosity: u8,
    fail_fast: bool,
    delayed_failures: Arc<Mutex<Vec<String>>>,
    command_cache: Arc<CommandCache>,
    profiler: Arc<CommandProfiler>,
}

Fields

dry_run: DryRunverbosity: u8fail_fast: booldelayed_failures: Arc<Mutex<Vec<String>>>command_cache: Arc<CommandCache>profiler: Arc<CommandProfiler>

Implementations

Source

impl ExecutionContext

pub(crate) fn new(verbosity: u8, fail_fast: bool) -> Self

pub(crate) fn dry_run(&self) -> bool

pub(crate) fn profiler(&self) -> &CommandProfiler

pub(crate) fn get_dry_run(&self) -> &DryRun

pub(crate) fn do_if_verbose(&self, f: impl Fn())

pub(crate) fn is_verbose(&self) -> bool

pub(crate) fn set_dry_run(&mut self, value: DryRun)

pub(crate) fn set_verbosity(&mut self, value: u8)

pub(crate) fn add_to_delay_failure(&self, message: String)

pub(crate) fn report_failures_and_exit(&self)

pub(crate) fn start<'a>( &self, command: &'a mut BootstrapCommand, stdout: OutputMode, stderr: OutputMode, ) -> DeferredCommand<'a>

Execute a command and return its output. Note: Ideally, you should use one of the BootstrapCommand::run* functions to execute commands. They internally call this method.

pub(crate) fn run( &self, command: &mut BootstrapCommand, stdout: OutputMode, stderr: OutputMode, ) -> CommandOutput

Execute a command and return its output. Note: Ideally, you should use one of the BootstrapCommand::run* functions to execute commands. They internally call this method.

fn fail(&self, message: &str) -> !

pub(crate) fn stream( &self, command: &mut BootstrapCommand, stdout: OutputMode, stderr: OutputMode, ) -> Option<StreamingCommand>

Spawns the command with configured stdout and stderr handling.

Returns None if in dry-run mode or Panics if the command fails to spawn.